// Type definitions for carbon-components-react 7.49
// Project: https://github.com/carbon-design-system/carbon/tree/master/packages/react
// Definitions by: Kyle Albert <https://github.com/kalbert312>
//                 Sebastien Gregoire <https://github.com/sgregoire>
//                 Mathias Schilling <https://github.com/matchilling>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 3.5

export as namespace CarbonReact;

//
// A note about 'next' components: This types package does not guarantee coverage of next components for
// carbon v11 mainly due to the complexity of carbon determining which component to use based on React context
// at runtime. Sometimes next props interfaces will conflict with the 'classic' variant. Additionally, next
// components may have dependencies on other next components. Because the component variant is determined
// at runtime, the components would need to be casted to the 'next' variant but for certain components
// like Button that have multiple overloads this becomes tricky.
//

// This group is primarily for type exports but will cover non-default exports as well.
export * from "./lib/components/Accordion";
export * from "./lib/components/AccordionItem";
export * from "./lib/components/AspectRatio";
export * from "./lib/components/Breadcrumb";
export * from "./lib/components/BreadcrumbItem";
export * from "./lib/components/Button";
export * from "./lib/components/ButtonSet";
export * from "./lib/components/Checkbox";
export * from "./lib/components/CodeSnippet";
export * from "./lib/components/ComboBox";
export * from "./lib/components/ComposedModal";
export * from "./lib/components/ContentSwitcher";
export * from "./lib/components/ContextMenu/useContextMenu";
export * from "./lib/components/Copy";
export * from "./lib/components/CopyButton";
export * from "./lib/components/DangerButton";
export * from "./lib/components/DataTable";
export * from "./lib/components/DataTableSkeleton";
export * from "./lib/components/DatePicker";
export * from "./lib/components/DatePickerInput";
export * from "./lib/components/Dropdown";
export * from "./lib/components/ErrorBoundary";
export * from "./lib/components/ExpandableSearch";
export * from "./lib/components/FileUploader";
export * from "./lib/components/FilterableMultiSelect";
export * from "./lib/components/FluidForm/FluidForm"; // context is not exported from index
export * from "./lib/components/Form";
export * from "./lib/components/FormGroup";
export * from "./lib/components/FormItem";
export * from "./lib/components/FormLabel";
export * from "./lib/components/Grid";
export * from "./lib/components/Icon";
export * from "./lib/components/InlineCheckbox";
export * from "./lib/components/InlineLoading";
export * from "./lib/components/Link";
export * from "./lib/components/ListBox";
export * from "./lib/components/ListItem";
export * from "./lib/components/Loading";
export * from "./lib/components/Menu/Menu";
export * from "./lib/components/Menu/MenuDivider";
export * from "./lib/components/Menu/MenuGroup";
export * from "./lib/components/Menu/MenuItem";
export * from "./lib/components/Menu/MenuRadioGroup";
export * from "./lib/components/Menu/MenuSelectableItem";
export * from "./lib/components/Modal";
export * from "./lib/components/ModalWrapper";
export * from "./lib/components/MultiSelect";
export * from "./lib/components/Notification";
export * from "./lib/components/NumberInput";
export * from "./lib/components/OrderedList";
export * from "./lib/components/OverflowMenu";
export * from "./lib/components/OverflowMenuItem";
export * from "./lib/components/Pagination";
export * from "./lib/components/PaginationNav";
export * from "./lib/components/Pagination/experimental/Pagination";
export * from "./lib/components/Pagination/experimental/PageSelector";
export * from "./lib/components/PasswordInput";
export * from "./lib/components/PrimaryButton";
export * from "./lib/components/ProgressBar";
export * from "./lib/components/ProgressIndicator";
export * from "./lib/components/RadioButton";
export * from "./lib/components/RadioButtonGroup";
export * from "./lib/components/RadioTile";
export * from "./lib/components/Search";
export * from "./lib/components/SearchFilterButton";
export * from "./lib/components/SearchLayoutButton";
export * from "./lib/components/SecondaryButton";
export * from "./lib/components/Select";
export * from "./lib/components/SelectItem";
export * from "./lib/components/SelectItemGroup";
export * from "./lib/components/SkeletonPlaceholder";
export * from "./lib/components/SkeletonText";
export * from "./lib/components/Slider";
export * from "./lib/components/StructuredList";
export * from "./lib/components/Switch";
export * from "./lib/components/Tab";
export * from "./lib/components/TabContent";
export * from "./lib/components/Tabs";
export * from "./lib/components/Tag";
export * from "./lib/components/TextArea";
export * from "./lib/components/TextInput";
export * from "./lib/components/Tile";
export * from "./lib/components/TileGroup";
export * from "./lib/components/TimePicker";
export * from "./lib/components/TimePickerSelect";
export * from "./lib/components/Toggle";
export * from "./lib/components/ToggleSmall";
export * from "./lib/components/Toolbar";
export * from "./lib/components/ToolbarSearch";
export * from "./lib/components/Tooltip";
export * from "./lib/components/TooltipDefinition";
export * from "./lib/components/TooltipIcon";
export * from "./lib/components/TreeView/TreeNode";
export * from "./lib/components/TreeView/TreeView";
export * from "./lib/components/UIShell";
export * from "./lib/components/UnorderedList";

export { default as Accordion } from "./lib/components/Accordion";
export { default as AccordionItem } from "./lib/components/AccordionItem";
export { AspectRatio } from "./lib/components/AspectRatio";
export { Breadcrumb, BreadcrumbItem } from "./lib/components/Breadcrumb";
export { default as Button } from "./lib/components/Button";
export { default as ButtonSet } from "./lib/components/ButtonSet";
export { default as Checkbox } from "./lib/components/Checkbox";
export { default as CodeSnippet } from "./lib/components/CodeSnippet";
export { default as ComboBox } from "./lib/components/ComboBox";
export { default as ComposedModal } from "./lib/components/ComposedModal";
export { ModalHeader, ModalBody, ModalFooter } from "./lib/components/ComposedModal";
export { default as ContentSwitcher } from "./lib/components/ContentSwitcher";
export {
    useContextMenu as unstable_useContextMenu,
} from "./lib/components/ContextMenu";
export { default as Copy } from "./lib/components/Copy";
export { default as CopyButton } from "./lib/components/CopyButton";
export { default as DangerButton } from "./lib/components/DangerButton";
export {
    default as DataTable,
    Table,
    TableActionList,
    TableBatchAction,
    TableBatchActions,
    TableBody,
    TableCell,
    TableContainer,
    TableExpandHeader,
    TableExpandRow,
    TableExpandedRow,
    TableHead,
    TableHeader,
    TableRow,
    TableSelectAll,
    TableSelectRow,
    TableToolbar,
    TableToolbarAction,
    TableToolbarContent,
    TableToolbarSearch,
    TableToolbarMenu,
} from "./lib/components/DataTable";
export { default as DatePicker } from "./lib/components/DatePicker";
export { default as DatePickerInput } from "./lib/components/DatePickerInput";
export { default as Dropdown } from "./lib/components/Dropdown";
export { ErrorBoundary, ErrorBoundaryContext } from "./lib/components/ErrorBoundary";
export { default as ExpandableSearch } from "./lib/components/ExpandableSearch";
export {
    FeatureFlags as unstable_FeatureFlags,
    useFeatureFlag as unstable_useFeatureFlag,
    useFeatureFlags as unstable_useFeatureFlags
} from "./lib/components/FeatureFlags";
export {
    default as FileUploader,
    Filename,
    FileUploaderButton,
    FileUploaderDropContainer,
    FileUploaderItem,
} from "./lib/components/FileUploader";
export { default as FilterableMultiSelect } from "./lib/components/FilterableMultiSelect";
export { default as FluidForm } from "./lib/components/FluidForm";
export { default as Form } from "./lib/components/Form";
export { default as FormGroup } from "./lib/components/FormGroup";
export { default as FormItem } from "./lib/components/FormItem";
export { default as FormLabel } from "./lib/components/FormLabel";
export { Column, Grid, Row } from "./lib/components/Grid";
export {
    Heading as unstable_Heading,
    HeadingProps as unstable_HeadingProps,
    Section as unstable_Section,
    SectionCustomComponentProps as unstable_SectionCustomComponentProps,
    SectionDefaultProps as unstable_SectionDefaultProps,
    SectionIntrinsicProps as unstable_SectionInstrinsicProps
} from "./lib/components/Heading";
export { default as Icon } from "./lib/components/Icon";
export { default as InlineLoading } from "./lib/components/InlineLoading";
export { default as Link } from "./lib/components/Link";
export { default as ListItem } from "./lib/components/ListItem";
export { default as Loading } from "./lib/components/Loading";
export {
    default as unstable_Menu,
    MenuDivider as unstable_MenuDivider,
    MenuGroup as unstable_MenuGroup,
    MenuItem as unstable_MenuItem,
    MenuRadioGroup as unstable_MenuRadioGroup,
    MenuSelectableItem as unstable_MenuSelectableItem,
} from "./lib/components/Menu";
export { default as Modal } from "./lib/components/Modal";
export { default as ModalWrapper } from "./lib/components/ModalWrapper";
export { default as MultiSelect } from "./lib/components/MultiSelect";
export {
    ToastNotification,
    InlineNotification,
    NotificationActionButton,
    NotificationButton,
    NotificationTextDetails,
} from "./lib/components/Notification";
export { default as NumberInput } from "./lib/components/NumberInput";
export { default as OrderedList } from "./lib/components/OrderedList";
export { default as OverflowMenu } from "./lib/components/OverflowMenu";
export { default as OverflowMenuItem } from "./lib/components/OverflowMenuItem";
export { default as Pagination } from "./lib/components/Pagination";
export { default as PaginationSkeleton } from "./lib/components/Pagination/Pagination.Skeleton";
export { default as PaginationNav } from "./lib/components/PaginationNav";
export { PageSelector as unstable_PageSelector } from "./lib/components/Pagination/experimental";
export { Pagination as unstable_Pagination } from "./lib/components/Pagination/experimental";
export { default as PrimaryButton } from "./lib/components/PrimaryButton";
export { default as unstable_ProgressBar } from "./lib/components/ProgressBar";
export { ProgressIndicator, ProgressStep } from "./lib/components/ProgressIndicator";
export { default as RadioButton } from "./lib/components/RadioButton";
export { default as RadioButtonGroup } from "./lib/components/RadioButtonGroup";
export { default as Search } from "./lib/components/Search";
export { default as SearchFilterButton } from "./lib/components/SearchFilterButton";
export { default as SearchLayoutButton } from "./lib/components/SearchLayoutButton";
export { default as SecondaryButton } from "./lib/components/SecondaryButton";
export { default as Select } from "./lib/components/Select";
export { default as SelectItem } from "./lib/components/SelectItem";
export { default as SelectItemGroup } from "./lib/components/SelectItemGroup";
export { default as Switch } from "./lib/components/Switch";
export { default as Slider } from "./lib/components/Slider";
export {
    StructuredListWrapper,
    StructuredListHead,
    StructuredListBody,
    StructuredListRow,
    StructuredListInput,
    StructuredListCell,
} from "./lib/components/StructuredList";
export { default as Tab } from "./lib/components/Tab";
export { default as TabContent } from "./lib/components/TabContent";
export { default as Tabs } from "./lib/components/Tabs";
export { default as Tag } from "./lib/components/Tag";
export { default as TextArea } from "./lib/components/TextArea";
export { default as TextInput } from "./lib/components/TextInput";
export {
    Tile,
    ClickableTile,
    SelectableTile,
    ExpandableTile,
    TileAboveTheFoldContent,
    TileBelowTheFoldContent,
} from "./lib/components/Tile";
export { default as RadioTile } from "./lib/components/RadioTile";
export { default as TileGroup } from "./lib/components/TileGroup";
export { default as TimePicker } from "./lib/components/TimePicker";
export { default as TimePickerSelect } from "./lib/components/TimePickerSelect";
export { default as Toggle } from "./lib/components/Toggle";
export { default as ToggleSmall } from "./lib/components/ToggleSmall";
export { default as Toolbar } from "./lib/components/Toolbar";
export { ToolbarItem, ToolbarTitle, ToolbarOption, ToolbarDivider } from "./lib/components/Toolbar";
export { default as ToolbarSearch } from "./lib/components/ToolbarSearch";
export { default as Tooltip } from "./lib/components/Tooltip";
export { default as TooltipDefinition } from "./lib/components/TooltipDefinition";
export { default as TooltipIcon } from "./lib/components/TooltipIcon";
export { default as unstable_TreeView } from "./lib/components/TreeView";
export { TreeNode as unstable_TreeNode } from "./lib/components/TreeView";
export { default as UnorderedList } from "./lib/components/UnorderedList";
export { default as SkeletonText } from "./lib/components/SkeletonText";
export { default as SkeletonPlaceholder } from "./lib/components/SkeletonPlaceholder";
export { default as DataTableSkeleton } from "./lib/components/DataTableSkeleton";
export { default as AccordionSkeleton } from "./lib/components/Accordion/Accordion.Skeleton";
export { default as BreadcrumbSkeleton } from "./lib/components/Breadcrumb/Breadcrumb.Skeleton";
export { default as ButtonSkeleton } from "./lib/components/Button/Button.Skeleton";
export { default as CheckboxSkeleton } from "./lib/components/Checkbox/Checkbox.Skeleton";
export { default as CodeSnippetSkeleton } from "./lib/components/CodeSnippet/CodeSnippet.Skeleton";
export { default as DropdownSkeleton } from "./lib/components/Dropdown/Dropdown.Skeleton";
export { default as FileUploaderSkeleton } from "./lib/components/FileUploader/FileUploader.Skeleton";
export { default as NumberInputSkeleton } from "./lib/components/NumberInput/NumberInput.Skeleton";
export { default as ProgressIndicatorSkeleton } from "./lib/components/ProgressIndicator/ProgressIndicator.Skeleton";
export { default as RadioButtonSkeleton } from "./lib/components/RadioButton/RadioButton.Skeleton";
export { default as SearchSkeleton } from "./lib/components/Search/Search.Skeleton";
export { default as SelectSkeleton } from "./lib/components/Select/Select.Skeleton";
export { default as SliderSkeleton } from "./lib/components/Slider/Slider.Skeleton";
export { default as TabsSkeleton } from "./lib/components/Tabs/Tabs.Skeleton";
export { default as TagSkeleton } from "./lib/components/Tag/Tag.Skeleton";
export { default as TextAreaSkeleton } from "./lib/components/TextArea/TextArea.Skeleton";
export { default as TextInputSkeleton } from "./lib/components/TextInput/TextInput.Skeleton";
export { default as ToggleSkeleton } from "./lib/components/Toggle/Toggle.Skeleton";
export { default as ToggleSmallSkeleton } from "./lib/components/ToggleSmall/ToggleSmall.Skeleton";
export { default as IconSkeleton } from "./lib/components/Icon/Icon.Skeleton";
export { default as DatePickerSkeleton } from "./lib/components/DatePicker/DatePicker.Skeleton";

export * from "./typings/translation";
