/*
 * Copyright 2020 The Kubernetes Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { dirname } from 'path';
export function _fwrite(_fullpath, data) {
    return __awaiter(this, void 0, void 0, function* () {
        const { mkdir, writeFile } = yield import('fs');
        const fullpath = _fullpath.replace(/"/g, ''); // trim double quotes
        yield new Promise((resolve, reject) => {
            const write = (path, data) => writeFile(path, data, err => {
                if (err) {
                    if (err.code === 'ENOENT') {
                        const error = new Error(err.message);
                        error.stack = err.stack;
                        error.code = 404;
                        reject(error);
                    }
                    else {
                        reject(err);
                    }
                }
                else {
                    resolve(true);
                }
            });
            const dir = dirname(fullpath);
            if (dir !== '.') {
                mkdir(dir, { recursive: true }, () => {
                    return write(fullpath, data);
                });
            }
            else {
                write(fullpath, data);
            }
        });
    });
}
/**
 * Kui command for fs.write
 *
 */
const fwrite = ({ argvNoOptions, execOptions }) => __awaiter(void 0, void 0, void 0, function* () {
    const fullpath = argvNoOptions[1];
    const data = execOptions.data;
    yield _fwrite(fullpath, data);
    return true;
});
function fwriteTemp(args) {
    return __awaiter(this, void 0, void 0, function* () {
        const { mkTemp } = yield import('./mkTemp');
        const data = args.execOptions.data;
        const { content: tmp } = yield mkTemp();
        yield _fwrite(tmp, data);
        return { mode: 'raw', content: tmp };
    });
}
/**
 * Register command handlers
 *
 */
export default (registrar) => {
    registrar.listen('/fwrite', fwrite, {
        hidden: true,
        requiresLocal: true
    });
    registrar.listen('/fwriteTemp', fwriteTemp, {
        hidden: true,
        requiresLocal: true
    });
};
//# sourceMappingURL=fwrite.js.map