/*
 * Copyright 2020 The Kubernetes Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import React from 'react';
import { isWatchable } from '@kui-shell/core';
import { KuiContext } from '../../../';
const PaginatedTable = React.lazy(() => import('./PaginatedTable'));
const LivePaginatedTable = React.lazy(() => import('./LivePaginatedTable'));
export default function renderTable(tab, repl, response, paginate = 20, toolbars = false, asGrid = false, onRender, isPartOfMiniSplit = false, isWidthConstrained = false) {
    if (isWatchable(response)) {
        return (React.createElement(React.Suspense, { fallback: React.createElement("div", null) },
            React.createElement(KuiContext.Consumer, null, config => (React.createElement(LivePaginatedTable, { tab: tab, repl: repl, config: config, response: response, paginate: paginate, title: !config.disableTableTitle, toolbars: toolbars, asGrid: asGrid, onRender: onRender, isPartOfMiniSplit: isPartOfMiniSplit, isWidthConstrained: isWidthConstrained })))));
    }
    else {
        return (React.createElement(React.Suspense, { fallback: React.createElement("div", null) },
            React.createElement(KuiContext.Consumer, null, config => {
                return (React.createElement(PaginatedTable, { tab: tab, repl: repl, config: config, response: response, paginate: paginate, title: !config.disableTableTitle, toolbars: toolbars, asGrid: asGrid, onRender: onRender, isPartOfMiniSplit: isPartOfMiniSplit, isWidthConstrained: isWidthConstrained }));
            })));
    }
}
//# sourceMappingURL=index.js.map